======
poshpy
======


.. image:: https://img.shields.io/pypi/v/poshpy.svg
        :target: https://pypi.python.org/pypi/poshpy

.. image:: https://github.com/BlueGhostLabs/poshpy/workflows/Tests/badge.svg?branch=main
        :target: https://github.com/BlueGhostLabs/poshpy/actions?query=workflow%3ATests

.. image:: https://readthedocs.org/projects/poshpy/badge/?version=latest
        :target: https://poshpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


A Python package for working with PowerShell.


* Free software: Apache-2.0
* Documentation: https://poshpy.readthedocs.io.


Features
--------

* Ability to execute PowerShell with a Command, EncodedCommand, or File option using Python.

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
